package com.xinelu.manage.service.subdivisioncategory;

import com.xinelu.manage.domain.subdivisioncategory.SubdivisionCategory;

import java.util.List;

/**
 * 细分类别信息Service接口
 *
 * @author xinelu
 * @date 2024-02-28
 */
public interface ISubdivisionCategoryService {
    /**
     * 查询细分类别信息
     *
     * @param id 细分类别信息主键
     * @return 细分类别信息
     */
    public SubdivisionCategory selectSubdivisionCategoryById(Long id);

    /**
     * 查询细分类别信息列表
     *
     * @param subdivisionCategory 细分类别信息
     * @return 细分类别信息集合
     */
    public List<SubdivisionCategory> selectSubdivisionCategoryList(SubdivisionCategory subdivisionCategory);

    /**
     * 新增细分类别信息
     *
     * @param subdivisionCategory 细分类别信息
     * @return 结果
     */
    public int insertSubdivisionCategory(SubdivisionCategory subdivisionCategory);

    /**
     * 修改细分类别信息
     *
     * @param subdivisionCategory 细分类别信息
     * @return 结果
     */
    public int updateSubdivisionCategory(SubdivisionCategory subdivisionCategory);

    /**
     * 批量删除细分类别信息
     *
     * @param ids 需要删除的细分类别信息主键集合
     * @return 结果
     */
    public int deleteSubdivisionCategoryByIds(Long[] ids);

    /**
     * 删除细分类别信息信息
     *
     * @param id 细分类别信息主键
     * @return 结果
     */
    public int deleteSubdivisionCategoryById(Long id);
}
